@@ -1,6 +1,8 @@
 
 
 class SafeStreamReader(object):
+    """recover stream current position after doing something will cause the position move.
+    """
 
     def __init__(self, stream):
         self.stream = stream
